==> gdal_3.12.0+dfsg.orig.tar.xz: gdal-3.12.0/apps/gdalalg_vsi.cpp <==
/******************************************************************************
 *
 * Project:  GDAL
 * Purpose:  gdal "vsi" subcommand
 * Author:   Even Rouault <even dot rouault at spatialys.com>
 *
 ******************************************************************************
 * Copyright (c) 2025, Even Rouault <even dot rouault at spatialys.com>
 *
 * SPDX-License-Identifier: MIT
 ****************************************************************************/

#include "gdalalgorithm.h"

#include "gdalalg_vsi_copy.h"
#include "gdalalg_vsi_delete.h"
#include "gdalalg_vsi_list.h"
#include "gdalalg_vsi_move.h"
#include "gdalalg_vsi_sync.h"
#include "gdalalg_vsi_sozip.h"

/************************************************************************/
/*                           GDALVSIAlgorithm                           */
/************************************************************************/

class GDALVSIAlgorithm final : public GDALAlgorithm
{
  public:
    static constexpr const char *NAME = "vsi";
    static constexpr const char *DESCRIPTION =
        "GDAL Virtual System Interface (VSI) commands.";
    static constexpr const char *HELP_URL = "/programs/gdal_vsi.html";

    GDALVSIAlgorithm() : GDALAlgorithm(NAME, DESCRIPTION, HELP_URL)
    {
        RegisterSubAlgorithm<GDALVSICopyAlgorithm>();
        RegisterSubAlgorithm<GDALVSIDeleteAlgorithm>();
        RegisterSubAlgorithm<GDALVSIListAlgorithm>();
        RegisterSubAlgorithm<GDALVSIMoveAlgorithm>();
        RegisterSubAlgorithm<GDALVSISyncAlgorithm>();
        RegisterSubAlgorithm<GDALVSISOZIPAlgorithm>();
    }

  private:
    bool RunImpl(GDALProgressFunc, void *) override;
};

bool GDALVSIAlgorithm::RunImpl(GDALProgressFunc, void *)
{
    CPLError(CE_Failure, CPLE_AppDefined,
             "The Run() method should not be called directly on the \"gdal "
             "vsi\" program.");
    return false;
}

GDAL_STATIC_REGISTER_ALG(GDALVSIAlgorithm);

==> gdal_3.12.2+dfsg.orig.tar.xz: gdal-3.12.2/apps/gdalalg_vsi.cpp <==
/******************************************************************************
 *
 * Project:  GDAL
 * Purpose:  gdal "vsi" subcommand
 * Author:   Even Rouault <even dot rouault at spatialys.com>
 *
 ******************************************************************************
 * Copyright (c) 2025, Even Rouault <even dot rouault at spatialys.com>
 *
 * SPDX-License-Identifier: MIT
 ****************************************************************************/

//! @cond Doxygen_Suppress

#include "gdalalg_vsi.h"

#include "gdalalg_vsi_copy.h"
#include "gdalalg_vsi_delete.h"
#include "gdalalg_vsi_list.h"
#include "gdalalg_vsi_move.h"
#include "gdalalg_vsi_sync.h"
#include "gdalalg_vsi_sozip.h"

/************************************************************************/
/*                           GDALVSIAlgorithm                           */
/************************************************************************/

GDALVSIAlgorithm::GDALVSIAlgorithm()
    : GDALAlgorithm(NAME, DESCRIPTION, HELP_URL)
{
    RegisterSubAlgorithm<GDALVSICopyAlgorithm>();
    RegisterSubAlgorithm<GDALVSIDeleteAlgorithm>();
    RegisterSubAlgorithm<GDALVSIListAlgorithm>();
    RegisterSubAlgorithm<GDALVSIMoveAlgorithm>();
    RegisterSubAlgorithm<GDALVSISyncAlgorithm>();
    RegisterSubAlgorithm<GDALVSISOZIPAlgorithm>();
}

bool GDALVSIAlgorithm::RunImpl(GDALProgressFunc, void *)
{
    CPLError(CE_Failure, CPLE_AppDefined,
             "The Run() method should not be called directly on the \"gdal "
             "vsi\" program.");
    return false;
}

//! @endcond
